PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/Misc.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Namespaces | Functions
Misc.hpp File Reference
`#include "Defs.hpp"`
`#include <cmath>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
namespace | math
namespace | math::approx

## Functions
constexpr Real | math::Radians (Real D)
template<typename T>
T | math::squared (T v)
float | math::approx::rsqrt (float x)
template<typename T>
T | math::reduce_max (const std::vector< T > &V)
template<typename T>
void | math::multiply (std::vector< T > &V, T s)